==> qtjambi-help-debuginfo-macos-5.15.17.jar: sources/QtJambiHelp/QHelpSearchResultWidget_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtHelp/qhelpsearchresultwidget.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>
#include <QtCore/qpoint.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qnamespace.h>
#include <QtGui/qevent.h>
#include <QtCore/qsize.h>
#include <QtGui/qkeysequence.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qwidget.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qregion.h>
#include <QtCore/qrect.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#include <QtCore/QList>
#include <QtGui/qfont.h>
#include <QtGui/qcursor.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qbackingstore.h>
#include <QtCore/qlocale.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qstyle.h>
#include <QtCore/qmargins.h>
#include <QtGui/qwindow.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qicon.h>
#include <QtGui/qpaintengine.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtGui/qfontmetrics.h>
#include <QtGui/qscreen.h>
#include <QtGui/qbitmap.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <QtCore/qtimer.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QHelpSearchResultWidget_0(){
    static int result = QMetaMethod::fromSignal(&QHelpSearchResultWidget::requestShowLink).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpSearchResultWidget::linkAt(QPoint)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResultWidget_linkAt_1native_1cref_1QPoint__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID point0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QHelpSearchResultWidget *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResultWidget>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpSearchResultWidget::linkAt(QPoint)", __qt_this)
        const QPoint& __qt_point0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(point0);
        QUrl __qt_return_value = __qt_this->linkAt(__qt_point0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QUrl_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType); // declared in QHelpContentWidget
bool nativeToJavaConverter_QUrl_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool); // declared in QHelpContentWidget

void initialize_meta_info_QHelpSearchResultWidget(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QHelpSearchResultWidget>("QHelpSearchResultWidget", "io/qt/help/QHelpSearchResultWidget");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QHelpSearchResultWidget::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "requestShowLink", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QHelpSearchResultWidget_0)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QHelpSearchResultWidget_0()){ // requestShowLink(const QUrl & url)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QUrl&
                                method.parameterType(0),
                                "io/qt/core/QUrl",
                                &nativeToJavaConverter_QUrl_cref,
                                &javaToNativeConverter_QUrl_cref);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(QPaintDevice), int(reinterpret_cast<quintptr>(static_cast<QPaintDevice *>(reinterpret_cast<QHelpSearchResultWidget *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-help-debuginfo-macos-6.5.4.jar: sources/QtJambiHelp/QHelpSearchResultWidget_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelpsearchresultwidget.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QHelpSearchResultWidget_0(){
    static int result = QMetaMethod::fromSignal(&QHelpSearchResultWidget::requestShowLink).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpSearchResultWidget::linkAt(QPoint)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResultWidget_linkAt_1native_1cref_1QPoint__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID point0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QHelpSearchResultWidget *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResultWidget>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpSearchResultWidget::linkAt(QPoint)", __qt_this)
        const QPoint& __qt_point0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(point0);
        QUrl __qt_return_value = __qt_this->linkAt(__qt_point0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QUrl_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType); // declared in QHelpContentWidget
bool nativeToJavaConverter_QUrl_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool); // declared in QHelpContentWidget

void initialize_meta_info_QHelpSearchResultWidget(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QHelpSearchResultWidget>("QHelpSearchResultWidget", "io/qt/help/QHelpSearchResultWidget");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QHelpSearchResultWidget::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "requestShowLink", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QHelpSearchResultWidget_0)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QHelpSearchResultWidget_0()){ // requestShowLink(const QUrl & url)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QUrl&
                                method.parameterType(0),
                                "io/qt/core/QUrl",
                                &nativeToJavaConverter_QUrl_cref,
                                &javaToNativeConverter_QUrl_cref);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(QPaintDevice), int(reinterpret_cast<quintptr>(static_cast<QPaintDevice *>(reinterpret_cast<QHelpSearchResultWidget *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}
